==> haskell-genvalidity-hspec-1.0.0.4-57-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-genvalidity-hspec.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 genvalidity-hspec
version:              1.0.0.4
visibility:           public
id:                   genvalidity-hspec-1.0.0.4-fGKhrVn76p5U4eoMoWlef
key:                  genvalidity-hspec-1.0.0.4-fGKhrVn76p5U4eoMoWlef
license:              MIT
copyright:            Copyright: (c) 2016-2021 Tom Sydney Kerckhove
maintainer:           syd@cs-syd.eu
author:               Tom Sydney Kerckhove
homepage:             https://github.com/NorfairKing/validity#readme
synopsis:             Standard spec'\''s for GenValidity instances
description:
    Note: There are companion packages for this library:

    * <https://hackage.haskell.org/package/genvalidity-hspec-aeson genvalidity-hspec-aeson>

    * <https://hackage.haskell.org/package/genvalidity-hspec-binary genvalidity-hspec-binary>

    * <https://hackage.haskell.org/package/genvalidity-hspec-cereal genvalidity-hspec-cereal>

    * <https://hackage.haskell.org/package/genvalidity-hspec-hashable genvalidity-hspec-hashable>

category:             Testing
abi:                  5d497b45d996a099b6d7f8f2f24a95f6
exposed:              True
exposed-modules:
    Test.Validity Test.Validity.Applicative Test.Validity.Arbitrary
    Test.Validity.Eq Test.Validity.Functor Test.Validity.GenValidity
    Test.Validity.Monad Test.Validity.Monoid Test.Validity.Ord
    Test.Validity.Show Test.Validity.Shrinking Test.Validity.Utils

hidden-modules:       Paths_genvalidity_hspec
import-dirs:          /usr/lib/ghc-9.4.8/site-local/genvalidity-hspec-1.0.0.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/genvalidity-hspec-1.0.0.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/genvalidity-hspec-1.0.0.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-genvalidity-hspec
hs-libraries:         HSgenvalidity-hspec-1.0.0.4-fGKhrVn76p5U4eoMoWlef
depends:
    QuickCheck-2.15.0.1-B00gWO2DVv5HBan67hNbs3 base-4.17.2.1
    genvalidity-1.1.1.0-EBIlr6MgVQn22Qck3vaCYI
    genvalidity-property-1.0.0.0-4LYsoAQhHCG8l93JV6XuEw
    hspec-2.11.3-3qKR9XcZpQB1G3Vj0rUm9Y
    hspec-core-2.11.3-7Oe50YMNBgo9ffiUqZvGnj transformers-0.5.6.2
    validity-0.12.1.0-HvaqpceoPix40iuXIisMVx

haddock-interfaces:
    /usr/share/doc/haskell-genvalidity-hspec/html/genvalidity-hspec.haddock

haddock-html:         /usr/share/doc/haskell-genvalidity-hspec/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-genvalidity-hspec-1.0.0.4-58-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-genvalidity-hspec.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 genvalidity-hspec
version:              1.0.0.4
visibility:           public
id:                   genvalidity-hspec-1.0.0.4-H0UcqrXzNOi78d8yxJPAbR
key:                  genvalidity-hspec-1.0.0.4-H0UcqrXzNOi78d8yxJPAbR
license:              MIT
copyright:            Copyright: (c) 2016-2021 Tom Sydney Kerckhove
maintainer:           syd@cs-syd.eu
author:               Tom Sydney Kerckhove
homepage:             https://github.com/NorfairKing/validity#readme
synopsis:             Standard spec'\''s for GenValidity instances
description:
    Note: There are companion packages for this library:

    * <https://hackage.haskell.org/package/genvalidity-hspec-aeson genvalidity-hspec-aeson>

    * <https://hackage.haskell.org/package/genvalidity-hspec-binary genvalidity-hspec-binary>

    * <https://hackage.haskell.org/package/genvalidity-hspec-cereal genvalidity-hspec-cereal>

    * <https://hackage.haskell.org/package/genvalidity-hspec-hashable genvalidity-hspec-hashable>

category:             Testing
abi:                  be95b0f0557dfc93ca8c0eb4969c712a
exposed:              True
exposed-modules:
    Test.Validity Test.Validity.Applicative Test.Validity.Arbitrary
    Test.Validity.Eq Test.Validity.Functor Test.Validity.GenValidity
    Test.Validity.Monad Test.Validity.Monoid Test.Validity.Ord
    Test.Validity.Show Test.Validity.Shrinking Test.Validity.Utils

hidden-modules:       Paths_genvalidity_hspec
import-dirs:          /usr/lib/ghc-9.4.8/site-local/genvalidity-hspec-1.0.0.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/genvalidity-hspec-1.0.0.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/genvalidity-hspec-1.0.0.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-genvalidity-hspec
hs-libraries:         HSgenvalidity-hspec-1.0.0.4-H0UcqrXzNOi78d8yxJPAbR
depends:
    QuickCheck-2.15.0.1-DUSZjYYOgXECqf7Svaitv8 base-4.17.2.1
    genvalidity-1.1.1.0-5jBCKWJ9yDd1i5LSEAYe9p
    genvalidity-property-1.0.0.0-A7NONU1JozJLOKOeqJpaMW
    hspec-2.11.3-BOHW1A2gcxo3KhBOKeiaIX
    hspec-core-2.11.3-4kzAlM4oXe71Uh8ebYRybr transformers-0.5.6.2
    validity-0.12.1.0-BPR1v6v5kXn9CDsUSx7JZ5

haddock-interfaces:
    /usr/share/doc/haskell-genvalidity-hspec/html/genvalidity-hspec.haddock

haddock-html:         /usr/share/doc/haskell-genvalidity-hspec/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
